ErrorCode class
- Inheritance
-
- Object
- ProtobufEnum
- ErrorCode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- IDENTITY_BEGIN → const ErrorCode
- IDENTITY_CONNECT_GOOGLE_API_FAILED → const ErrorCode
- IDENTITY_DB_EXECUTION_FAILED → const ErrorCode
- IDENTITY_END → const ErrorCode
- IDENTITY_EXPIRY_INVALID → const ErrorCode
- IDENTITY_EXPIRY_NOT_FOUND → const ErrorCode
- IDENTITY_GENERATE_JWT_UNSUCCESSFULLY → const ErrorCode
- IDENTITY_GENERATE_PASSWORD_UNSUCCESSFULLY → const ErrorCode
- IDENTITY_GOOGLE_EMAIL_UNVERIFIED → const ErrorCode
- IDENTITY_GOOGLE_TOKEN_EXPIRED → const ErrorCode
- IDENTITY_GOOGLE_TOKEN_INVALID → const ErrorCode
- IDENTITY_INVALID_PASSWORD → const ErrorCode
- IDENTITY_ISSUE_AT_INVALID → const ErrorCode
- IDENTITY_ISSUE_AT_NOT_FOUND → const ErrorCode
- IDENTITY_LP_ADMIN_NOT_FOUND → const ErrorCode
- IDENTITY_MARSHAL_FAILED → const ErrorCode
- IDENTITY_NEW_PASSWORD_MUST_BE_DIFFERENT → const ErrorCode
- IDENTITY_PARSING_FAILED → const ErrorCode
- IDENTITY_UNMARSHAL_FAILED → const ErrorCode
- IDENTITY_USER_OR_UUID_INVALID → const ErrorCode
- IDENTITY_USER_TYPE_INVALID → const ErrorCode
- IDENTITY_USER_TYPE_NOT_FOUND → const ErrorCode
- IDENTITY_VALIDATE_FAILED → const ErrorCode
- IDENTITY_VERIFY_JWT_FAILED → const ErrorCode
-
values
→ const List<
ErrorCode>