IdentityServiceBase class abstract

Annotations
  • @GrpcServiceName.new('identity.Identity')

Constructors

IdentityServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
approveUser(ServiceCall call, ApproveUserRequest request) Future<ApproveUserReply>
approveUser_Pre(ServiceCall call, Future<ApproveUserRequest> request) Future<ApproveUserReply>
forgotPassword(ServiceCall call, ForgotPasswordRequest request) Future<ForgotPasswordReply>
forgotPassword_Pre(ServiceCall call, Future<ForgotPasswordRequest> request) Future<ForgotPasswordReply>
getUser(ServiceCall call, GetUserRequest request) Future<GetUserReply>
getUser_Pre(ServiceCall call, Future<GetUserRequest> request) Future<GetUserReply>
googleAuthen(ServiceCall call, GoogleAuthenRequest request) Future<GoogleAuthenReply>
googleAuthen_Pre(ServiceCall call, Future<GoogleAuthenRequest> request) Future<GoogleAuthenReply>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resendOtp(ServiceCall call, ResendOtpRequest request) Future<ResendOtpReply>
resendOtp_Pre(ServiceCall call, Future<ResendOtpRequest> request) Future<ResendOtpReply>
resetPassword(ServiceCall call, ResetPasswordRequest request) Future<ResetPasswordReply>
resetPassword_Pre(ServiceCall call, Future<ResetPasswordRequest> request) Future<ResetPasswordReply>
signIn(ServiceCall call, SignInRequest request) Future<SignInReply>
signIn_Pre(ServiceCall call, Future<SignInRequest> request) Future<SignInReply>
signUp(ServiceCall call, SignUpRequest request) Future<SignUpReply>
signUp_Pre(ServiceCall call, Future<SignUpRequest> request) Future<SignUpReply>
toString() String
A string representation of this object.
inherited
updateUserStatus(ServiceCall call, UpdateUserStatusRequest request) Future<UpdateUserStatusReply>
updateUserStatus_Pre(ServiceCall call, Future<UpdateUserStatusRequest> request) Future<UpdateUserStatusReply>
verifyOtp(ServiceCall call, VerifyOtpRequest request) Future<VerifyOtpReply>
verifyOtp_Pre(ServiceCall call, Future<VerifyOtpRequest> request) Future<VerifyOtpReply>
verifyToken(ServiceCall call, VerifyTokenRequest request) Future<VerifyTokenReply>
verifyToken_Pre(ServiceCall call, Future<VerifyTokenRequest> request) Future<VerifyTokenReply>

Operators

operator ==(Object other) bool
The equality operator.
inherited