CurrencyPair class
- Inheritance
-
- Object
- ProtobufEnum
- CurrencyPair
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → CurrencyPair?
Constants
- AUD_USDT → const CurrencyPair
- CAD_USDT → const CurrencyPair
- CNY_USDT → const CurrencyPair
- HKD_USDT → const CurrencyPair
- IDR_USDT → const CurrencyPair
- JPY_USDT → const CurrencyPair
- KHR_USDT → const CurrencyPair
- KRW_USDT → const CurrencyPair
- MYR_USDT → const CurrencyPair
- PAIR_UNSPECIFIED → const CurrencyPair
- PHP_USDT → const CurrencyPair
- SAR_USDT → const CurrencyPair
- SGD_USDT → const CurrencyPair
- THB_USDT → const CurrencyPair
-
values
→ const List<
CurrencyPair> - VND_USDT → const CurrencyPair