OrderStatus class

BUY : pending -> accepted LP -> token locked LP -> senfing fiat (User-LP) -> User confirmed -> LP confirmed -> transfering token User -> blockchain success SELL : pending -> token locked User -> accepted LP -> sending fiat (LP-User) -> LP confirmed -> User confirmed -> transfering token LP -> blockchain success

Inheritance
  • Object
  • ProtobufEnum
  • OrderStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) OrderStatus?