ErrorCode class
- Inheritance
-
- Object
- ProtobufEnum
- ErrorCode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- SWEEP_BEGIN → const ErrorCode
- SWEEP_DB_EXECUTION_FAILED → const ErrorCode
- SWEEP_END → const ErrorCode
- SWEEP_GENERATE_JWT_UNSUCCESSFULLY → const ErrorCode
- SWEEP_MARSHAL_FAILED → const ErrorCode
- SWEEP_UNMARSHAL_FAILED → const ErrorCode
- SWEEP_VALIDATE_FAILED → const ErrorCode
- SWEEP_VERIFY_JWT_FAILED → const ErrorCode
- SWEEP_VERIFY_ROLE_FAILED → const ErrorCode
- SWEEP_ZERO_USER → const ErrorCode
-
values
→ const List<
ErrorCode>