ErrorCode class
- Inheritance
-
- Object
- ProtobufEnum
- ErrorCode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ErrorCode> - WALLET_ADDRESS_NOT_FOUND → const ErrorCode
- WALLET_BALANCE_OF_NOT_FOUND → const ErrorCode
- WALLET_BEGIN → const ErrorCode
- WALLET_BROADCAST_TRANSACTION_UNSUCCESSFULLY → const ErrorCode
- WALLET_CREATE_TRANSACTION_UNSUCCESSFULLY → const ErrorCode
- WALLET_DB_EXECUTION_FAILED → const ErrorCode
- WALLET_DECRYPT_FAILED → const ErrorCode
- WALLET_ENCRYPT_FAILED → const ErrorCode
- WALLET_END → const ErrorCode
- WALLET_GENERATE_JWT_UNSUCCESSFULLY → const ErrorCode
- WALLET_GENERATE_SIGNATURE_FAILED → const ErrorCode
- WALLET_IVALID_DATA → const ErrorCode
- WALLET_MARSHAL_FAILED → const ErrorCode
- WALLET_NEMONIC_EXISTED → const ErrorCode
- WALLET_NEMONIC_NON_EXISTED → const ErrorCode
- WALLET_PRIVKEY_NOT_FOUND → const ErrorCode
- WALLET_RETRIEVE_ADMIN_FAILED → const ErrorCode
- WALLET_RETRIEVE_MASTER_SEED_FAILED → const ErrorCode
- WALLET_SIGN_TRANSACTION_UNSUCCESSFULLY → const ErrorCode
- WALLET_SIGN_UP_VAULT_FAILED → const ErrorCode
- WALLET_TRANSACTION_RESULT_FAILED → const ErrorCode
- WALLET_UNMARSHAL_FAILED → const ErrorCode
- WALLET_UNSUPPORTED_ASSET → const ErrorCode
- WALLET_UNSUPPORTED_CURRENCY → const ErrorCode
- WALLET_UPDATE_USER_STATUS_FAILED → const ErrorCode
- WALLET_VALIDATE_FAILED → const ErrorCode
- WALLET_VAULT_ADDRESS_EXIST → const ErrorCode
- WALLET_VERIFY_JWT_FAILED → const ErrorCode
- WALLET_VERIFY_ROLE_FAILED → const ErrorCode