Order class
Constructors
-
Order({String? key, String? id, String? rev, String? uuid, String? createdAt, String? updatedAt, String? expiryAt, String? merchantId, String? userId, String? lpId, CurrencyPair? pair, double? fiat, double? price, Int64? token, String? idLocked, Int64? timestamp, OrderType? orderType, OrderStatus? status, Iterable<State>? states, BankDetail? lpBank, BankDetail? userBank, String? reffNumber, String? qrCode, String? signature, double? vwap, Int64? balance, String? lpAdminId, Int64? profitLoss})
-
factory
-
Order.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
-
factory
-
Order.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
-
factory
Methods
-
addExtension(Extension extension, Object? value)
→ void
-
Adds an extension field value to a repeated field.
inherited
-
check()
→ void
-
inherited
-
clear()
→ void
-
Clears all data that was set in this message.
inherited
-
clearBalance()
→ void
-
-
clearCreatedAt()
→ void
-
-
clearExpiryAt()
→ void
-
-
clearExtension(Extension extension)
→ void
-
Clears an extension field and also removes the extension.
inherited
-
clearFiat()
→ void
-
-
clearField(int tagNumber)
→ void
-
Clears the contents of a given field.
inherited
-
clearId()
→ void
-
-
clearIdLocked()
→ void
-
-
clearKey()
→ void
-
-
clearLpAdminId()
→ void
-
-
clearLpBank()
→ void
-
-
clearLpId()
→ void
-
-
clearMerchantId()
→ void
-
-
clearOrderType()
→ void
-
-
clearPair()
→ void
-
-
clearPrice()
→ void
-
-
clearProfitLoss()
→ void
-
-
clearQrCode()
→ void
-
-
clearReffNumber()
→ void
-
-
clearRev()
→ void
-
-
clearSignature()
→ void
-
-
clearStatus()
→ void
-
-
clearTimestamp()
→ void
-
-
clearToken()
→ void
-
-
clearUpdatedAt()
→ void
-
-
clearUserBank()
→ void
-
-
clearUserId()
→ void
-
-
clearUuid()
→ void
-
-
clearVwap()
→ void
-
-
clone()
→ Order
-
Creates a deep copy of the fields in this message.
(The generated code uses mergeFromMessage.)
override
-
copyWith(void updates(Order))
→ Order
-
Apply
updates to a copy of this message.
override
-
createEmptyInstance()
→ Order
-
Creates an empty instance of the same message type as this.
override
-
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi)
→ Map<K, V>
-
Creates a Map representing a map field.
inherited
-
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi)
→ List<T>
-
Creates List implementing a mutable repeated field.
inherited
-
ensureLpBank()
→ BankDetail
-
-
ensureUserBank()
→ BankDetail
-
-
extensionsAreInitialized()
→ bool
-
inherited
-
freeze()
→ GeneratedMessage
-
Make this message read-only.
inherited
-
getDefaultForField(int tagNumber)
→ dynamic
-
Returns the default value for the given field.
inherited
-
getExtension(Extension extension)
→ dynamic
-
Returns the value of
extension.
inherited
-
getField(int tagNumber)
→ dynamic
-
Returns the value of the field associated with
tagNumber, or the
default value if it is not set.
inherited
-
getFieldOrNull(int tagNumber)
→ dynamic
-
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(String fieldName)
→ int?
-
inherited
-
hasBalance()
→ bool
-
-
hasCreatedAt()
→ bool
-
-
hasExpiryAt()
→ bool
-
-
hasExtension(Extension extension)
→ bool
-
Returns
true if a value of extension is present.
inherited
-
hasFiat()
→ bool
-
-
hasField(int tagNumber)
→ bool
-
Whether this message has a field associated with
tagNumber.
inherited
-
hasId()
→ bool
-
-
hasIdLocked()
→ bool
-
-
hasKey()
→ bool
-
-
hasLpAdminId()
→ bool
-
-
hasLpBank()
→ bool
-
-
hasLpId()
→ bool
-
-
hasMerchantId()
→ bool
-
-
hasOrderType()
→ bool
-
-
hasPair()
→ bool
-
-
hasPrice()
→ bool
-
-
hasProfitLoss()
→ bool
-
-
hasQrCode()
→ bool
-
-
hasReffNumber()
→ bool
-
-
hasRequiredFields()
→ bool
-
Whether the message has required fields.
inherited
-
hasRev()
→ bool
-
-
hasSignature()
→ bool
-
-
hasStatus()
→ bool
-
-
hasTimestamp()
→ bool
-
-
hasToken()
→ bool
-
-
hasUpdatedAt()
→ bool
-
-
hasUserBank()
→ bool
-
-
hasUserId()
→ bool
-
-
hasUuid()
→ bool
-
-
hasVwap()
→ bool
-
-
isInitialized()
→ bool
-
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
inherited
-
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges field values from
data, a JSON object, encoded as described by
GeneratedMessage.writeToJson.
inherited
-
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(GeneratedMessage other)
→ void
-
Merges the contents of the
other into this message.
inherited
-
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false})
→ void
-
Merges field values from
json, a JSON object using proto3 encoding.
inherited
-
mergeUnknownFields(UnknownFieldSet unknownFieldSet)
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setExtension(Extension extension, Object value)
→ void
-
Sets the value of a non-repeated extension field to
value.
inherited
-
setField(int tagNumber, Object value)
→ void
-
Sets the value of a field by its
tagNumber.
inherited
-
toBuilder()
→ GeneratedMessage
-
Creates a writable, shallow copy of this message.
inherited
-
toDebugString()
→ String
-
Returns a String representation of this message.
inherited
-
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()})
→ Object?
-
Returns an Object representing Proto3 JSON serialization of
this.
inherited
-
toString()
→ String
-
Returns a String representation of this message.
inherited
-
writeToBuffer()
→ Uint8List
-
inherited
-
writeToCodedBufferWriter(CodedBufferWriter output)
→ void
-
inherited
-
writeToJson()
→ String
-
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap()
→ Map<String, dynamic>
-
Returns the JSON encoding of this message as a Dart Map.
inherited