ErrorCode class
- Inheritance
-
- Object
- ProtobufEnum
- ErrorCode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- PAYMENT_BANK_NOT_FOUND → const ErrorCode
- PAYMENT_BEGIN → const ErrorCode
- PAYMENT_BROADCAST_TRANSACTION_UNSUCCESSFULLY → const ErrorCode
- PAYMENT_CREATE_TRANSACTION_UNSUCCESSFULLY → const ErrorCode
- PAYMENT_DB_ABORT_TX_FAILED → const ErrorCode
- PAYMENT_DB_BEGIN_TX_FAILED → const ErrorCode
- PAYMENT_DB_COMMIT_TX_FAILED → const ErrorCode
- PAYMENT_DB_EXECUTION_FAILED → const ErrorCode
- PAYMENT_DUPLICATE_PAIR → const ErrorCode
- PAYMENT_END → const ErrorCode
- PAYMENT_EXPORT_PRIVKEY_FAILED → const ErrorCode
- PAYMENT_GENERATE_JWT_UNSUCCESSFULLY → const ErrorCode
- PAYMENT_GENERATE_SIGNATURE_FAILED → const ErrorCode
- PAYMENT_GET_BALANACE_OF_BY_ADDRESS_FAILED → const ErrorCode
- PAYMENT_GET_QUOTE_PRICE_FAILED → const ErrorCode
- PAYMENT_INVALID_DATE → const ErrorCode
- PAYMENT_LP_PROFILE_NOT_FOUND → const ErrorCode
- PAYMENT_MARSHAL_FAILED → const ErrorCode
- PAYMENT_MERCHANT_BALANCE_NOT_ENOUGH → const ErrorCode
- PAYMENT_METHOD_APPROVE_NOT_IMPLEMENTED → const ErrorCode
- PAYMENT_MISMATCH_LP_ID → const ErrorCode
- PAYMENT_ORDER_ALREADY_TAGGED → const ErrorCode
- PAYMENT_ORDER_CALCULATE_PROFIT_LOSS_FAILED → const ErrorCode
- PAYMENT_OVERFLOW → const ErrorCode
- PAYMENT_PRICE_NOT_FOUND → const ErrorCode
- PAYMENT_SIGN_TRANSACTION_UNSUCCESSFULLY → const ErrorCode
- PAYMENT_STATUS_WRONG → const ErrorCode
- PAYMENT_TIMESTAMP_NOT_CORRECT → const ErrorCode
- PAYMENT_TOKEN_NOT_ENOUGH → const ErrorCode
- PAYMENT_TRANSACTION_NOT_FOUND → const ErrorCode
- PAYMENT_UNMARSHAL_FAILED → const ErrorCode
- PAYMENT_USER_ID_NOT_SAME → const ErrorCode
- PAYMENT_VALIDATE_FAILED → const ErrorCode
- PAYMENT_VAULT_ADDRESS_NOT_FOUND → const ErrorCode
- PAYMENT_VERIFY_JWT_FAILED → const ErrorCode
- PAYMENT_VERIFY_ROLE_FAILED → const ErrorCode
- PAYMENT_VERIFYING_SIGNATURE_FAILED → const ErrorCode
- PAYMENT_WALLET_NOT_FOUND → const ErrorCode
- PAYMENT_ZERO_PENDING_ORDER → const ErrorCode
-
values
→ const List<
ErrorCode>