ProfileClient class

Annotations
  • @GrpcServiceName.new('profile.Profile')

Constructors

ProfileClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addUser(AddUserRequest request, {CallOptions? options}) → ResponseFuture<AddUserReply>
approve(ApproveRequest request, {CallOptions? options}) → ResponseFuture<ApproveReply>
ban(BanRequest request, {CallOptions? options}) → ResponseFuture<BanReply>
getAccountByEmail(GetAccountByEmailRequest request, {CallOptions? options}) → ResponseFuture<GetAccountByEmailReply>
getAccountById(GetAccountByIdRequest request, {CallOptions? options}) → ResponseFuture<GetAccountByIdReply>
getListAccounts(GetListAccountsRequest request, {CallOptions? options}) → ResponseFuture<GetListAccountsReply>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setRoles(SetRolesRequest request, {CallOptions? options}) → ResponseFuture<SetRolesReply>
toString() String
A string representation of this object.
inherited
updateKyc(UpdateKycRequest request, {CallOptions? options}) → ResponseFuture<UpdateKycReply>

Operators

operator ==(Object other) bool
The equality operator.
inherited