- Annotations
-
- @GrpcServiceName.new('profile.Profile')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
addUser(ServiceCall call, AddUserRequest request)
→ Future<AddUserReply>
-
-
addUser_Pre(ServiceCall call, Future<AddUserRequest> request)
→ Future<AddUserReply>
-
-
approve(ServiceCall call, ApproveRequest request)
→ Future<ApproveReply>
-
-
approve_Pre(ServiceCall call, Future<ApproveRequest> request)
→ Future<ApproveReply>
-
-
ban(ServiceCall call, BanRequest request)
→ Future<BanReply>
-
-
ban_Pre(ServiceCall call, Future<BanRequest> request)
→ Future<BanReply>
-
-
getAccountByEmail(ServiceCall call, GetAccountByEmailRequest request)
→ Future<GetAccountByEmailReply>
-
-
getAccountByEmail_Pre(ServiceCall call, Future<GetAccountByEmailRequest> request)
→ Future<GetAccountByEmailReply>
-
-
getAccountById(ServiceCall call, GetAccountByIdRequest request)
→ Future<GetAccountByIdReply>
-
-
getAccountById_Pre(ServiceCall call, Future<GetAccountByIdRequest> request)
→ Future<GetAccountByIdReply>
-
-
getListAccounts(ServiceCall call, GetListAccountsRequest request)
→ Future<GetListAccountsReply>
-
-
getListAccounts_Pre(ServiceCall call, Future<GetListAccountsRequest> request)
→ Future<GetListAccountsReply>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setRoles(ServiceCall call, SetRolesRequest request)
→ Future<SetRolesReply>
-
-
setRoles_Pre(ServiceCall call, Future<SetRolesRequest> request)
→ Future<SetRolesReply>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateKyc(ServiceCall call, UpdateKycRequest request)
→ Future<UpdateKycReply>
-
-
updateKyc_Pre(ServiceCall call, Future<UpdateKycRequest> request)
→ Future<UpdateKycReply>
-